function  z = GeneExpressionSDE(Ste12a)
tic;
    tfinal = 13000;
    stepsize = .1;
    L = tfinal/stepsize;
    tvals = 0:stepsize:tfinal;
    tau = stepsize;
    NoiseScaling = 0.05;
    
    %stoichiometric matrix
    V = [1 -1 0 0 0;0 0 1 -1 0;0 0 0 1 -1];
    
    %%%%%%%%%% Parameters and Initial Conditions %%%%%%%%%
    nA = 6.023e23;              % Avagadro's number
    vol = 29e-15;               % volume of Yeast Cell 
    Y = zeros(3,1);             
    D = round(Ste12a*10^-6*nA*vol);


    c(1) = 8.376523998593117e-08; %mRNA Synthesis Rate
    c(2) = 2.155839679306574; %mRNA Degradation Rate
    c(3) = 2.717203164733281e+03; %Nascent GFP Synthesis Rate
    c(4) = 2.724573018572289e-04; %Mature GFP Synthesis Rate
    c(5) = 3.052810074235267e-04; %Mature GFP Degradation Rate


    Yvals = zeros(3,L+1);
    Yvals(1,1) = Y(1);
    Yvals(2,1) = Y(2);
    Yvals(3,1) = Y(3);
%     h = waitbar(0,'Please wait...');

    for k = 1:L
        a(1) = c(1)*D(k);
        a(2) = c(2)*Y(1);
        a(3) = c(3)*Y(1);
        a(4) = c(4)*Y(2);
        a(5) = c(5)*Y(3);
        
        d(1) = tau*a(1) + NoiseScaling*sqrt(abs(tau*a(1)))*randn;
        d(2) = tau*a(2) + NoiseScaling*sqrt(abs(tau*a(2)))*randn;
        d(3) = tau*a(3) + NoiseScaling*sqrt(abs(tau*a(3)))*randn;
        d(4) = tau*a(4) + NoiseScaling*sqrt(abs(tau*a(4)))*randn;
        d(5) = tau*a(5) + NoiseScaling*sqrt(abs(tau*a(5)))*randn;
        
        Y = Y + d(1)*V(:,1) + d(2)*V(:,2) + d(3)*V(:,3)+d(4)*V(:,4)+d(5)*V(:,5);
        Yvals(:,k+1) = Y/(10^-6*nA*vol);
%         waitbar(k/L);
        z = Yvals(3,:);
    end
%             plot(tvals,Yvals(3,:),'g-');
%             close(h);
            toc;
end

% for j = 1
% Wb = waitbar(0,'Please wait...');
% 
% 
% CellCount = 1;
% for i = 1 : CellCount
% 
% PstochasticN = [PstochasticN;Yvals(3,:)];
% hold on;
% waitbar(i/CellCount);
% 
% %save(savefile,'Pstochastic');
% 
% end
% close(Wb);
% hold off;
% end;
